// -- FILE ------------------------------------------------------------------
// name       : PluginClassLoader.java
// project    : BoarderZone: Libraries
// created    : Leon Poyyayil - 2005.06.26
// language   : java
// environment: JDK 1.5.0
// copyright  : (c) 1990-2008 by Leon Poyyayil (private), Switzerland
// license    : this is free software licensed under the GPL. see COPYING
// --------------------------------------------------------------------------
package net.boarderzone.plugin;


// -- CLASS -----------------------------------------------------------------
/** Utility class to make a PluginFactory available as a standard ClassLoader.
@author   Leon Poyyayil
@version  0.8.458
@since    0.4.225
*///-------------------------------------------------------------------------
public final class PluginClassLoader extends ClassLoader {


// ----- constants -----
/** provides version information for this class/package */
public static final VersionInfo VERSION_INFO = VersionInfo.getInstance();


// -- METHOD ----------------------------------------------------------------
/** Creates a new instance which uses the system ClassLoader as its parent.
@since    0.4.225
@param    pFactory the factory to use for loading and verifying the plugin classes
*///-------------------------------------------------------------------------
public PluginClassLoader(
  final PluginFactory pFactory
)
{
  this( pFactory, ClassLoader.getSystemClassLoader() );
} // PluginClassLoader


// -- METHOD ----------------------------------------------------------------
/** Creates a new instance the given parent ClassLoader.
@since    0.4.225
@param    pFactory the factory to use for loading and verifying the plugin classes
@param    pParent the parent ClassLoader to use for delegation
*///-------------------------------------------------------------------------
public PluginClassLoader(
  final PluginFactory pFactory,
  final ClassLoader   pParent
)
{
  super( pParent );
  if ( pFactory == null ) {
    throw new NullPointerException();
  }
  mFactory = pFactory;
} // PluginClassLoader


// -- METHOD ----------------------------------------------------------------
/** {@inheritDoc} This attempts to load the class using the embedded PluginFactory.
If that fails for any plugin specific error, a ClassNotFoundException is raised too.
@since    0.4.225
*///-------------------------------------------------------------------------
protected Class findClass(
  final String pName
) throws ClassNotFoundException
{
  try {
    return mFactory.loadPluginClass( pName );
  } catch ( PluginException pExc ) {
    throw new ClassNotFoundException( pExc.getMessage(), pExc );
  }
} // findClass


// ----- members -----
/** the factory to use for loading and verifying the plugin classes */
private PluginFactory mFactory;


} // class PluginClassLoader
// --------------------------------------------------------------------------


// -- EOF -------------------------------------------------------------------
