// -- FILE ------------------------------------------------------------------
// name       : PluginFactory.java
// project    : BoarderZone: Libraries
// created    : Leon Poyyayil - 2005.06.25
// language   : java
// environment: JDK 1.5.0
// copyright  : (c) 1990-2008 by Leon Poyyayil (private), Switzerland
// license    : this is free software licensed under the GPL. see COPYING
// --------------------------------------------------------------------------
package net.boarderzone.plugin;


// -- CLASS -----------------------------------------------------------------
/** Contract for a factory to instantiate plugins.
@author   Leon Poyyayil
@version  0.8.458
@since    0.4.225
*///-------------------------------------------------------------------------
public interface PluginFactory {


// ----- constants -----
/** provides version information for this class/package */
public static final VersionInfo VERSION_INFO = VersionInfo.getInstance();


// -- METHOD ----------------------------------------------------------------
/** Loads the class of the plugin. This method must perform the checks necessary
to make sure the loaded plugin class will run properly in the current host
environment: it checks whether the host supports the version of the plugin
and whether the plugin supports being hosted in the hosts version.
@since    0.4.225
@param    pPluginClassName the name of the class implementing the plugin
@return   the class with the given name
@throws   PluginIncompatibleException in case either the host or the plugin
          rejects the other's version
@throws   PluginNotFoundException in case no plugin with the given name could
          be loaded successfully
*///-------------------------------------------------------------------------
public Class loadPluginClass(
  final String pPluginClassName
) throws PluginIncompatibleException, PluginNotFoundException;


// -- METHOD ----------------------------------------------------------------
/** Instantiates a plugin of the given class. This method must perform the
checks necessary to make sure the loaded plugin will run properly in the current
host environment: it checks whether the host supports the version of the plugin
and whether the plugin supports being hosted in the hosts version.
@since    0.4.225
@param    pPluginClassName the name of the concrete class of the plugin to instantiate.
@return   a new instance of the given class, guaranteed to be compatible with the
          current host environment.
@throws   PluginIncompatibleException in case either the host or the plugin
          rejects the other's version
@throws   PluginNotFoundException in case no plugin with the given name could
          be loaded successfully
*///-------------------------------------------------------------------------
public Object createPlugin(
  final String pPluginClassName
) throws PluginIncompatibleException, PluginNotFoundException;


} // interface PluginFactory
// --------------------------------------------------------------------------


// -- EOF -------------------------------------------------------------------
