// -- FILE ------------------------------------------------------------------
// name       : PluginHostRequirements.java
// project    : BoarderZone: Libraries
// created    : Leon Poyyayil - 2005.06.25
// language   : java
// environment: JDK 1.5.0
// copyright  : (c) 1990-2008 by Leon Poyyayil (private), Switzerland
// license    : this is free software licensed under the GPL. see COPYING
// --------------------------------------------------------------------------
package net.boarderzone.plugin;

import net.boarderzone.util.ImmutableVersion;
import net.boarderzone.util.Version;


// -- CLASS -----------------------------------------------------------------
/** Defines the requirements of a plugin host for plugins.
@author   Leon Poyyayil
@version  0.8.458
@since    0.4.225
*///-------------------------------------------------------------------------
public final class PluginHostRequirements {


// ----- constants -----
/** provides version information for this class/package */
public static final VersionInfo VERSION_INFO = VersionInfo.getInstance();


// -- METHOD ----------------------------------------------------------------
/** Creates a new instance with the given parameters.
@since    0.4.225
@param    pPluginInterface the class of the expected plugin interface a plugin
          should implement. may not be null.
@param    pMinRequiredVersion the minimum version the plugin must be of in order
          to be acceptable. may not be null.
@throws   NullPointerException in case of a null argument
@throws   IllegalArgumentException in case the given class is no interface
*///-------------------------------------------------------------------------
public PluginHostRequirements(
  final Class   pPluginInterface,
  final Version pMinRequiredVersion
)
{
  if ( !pPluginInterface.isInterface() ) {
    throw new IllegalArgumentException(
      "the given class is no interface: " + pPluginInterface.getName() );
  }
  mPluginInterface = pPluginInterface;
  mMinRequiredVersion = new ImmutableVersion( pMinRequiredVersion );
} // PluginHostRequirements


// -- METHOD ----------------------------------------------------------------
/** Accessor for PluginInterface.
@since    0.4.225
@return   the PluginInterface
*///-------------------------------------------------------------------------
public final Class getPluginInterface()
{
  return mPluginInterface;
} // getPluginInterface


// -- METHOD ----------------------------------------------------------------
/** Accessor for MinRequiredVersion.
@since    0.4.225
@return   the MinRequiredVersion
*///-------------------------------------------------------------------------
public final ImmutableVersion getMinRequiredVersion()
{
  return mMinRequiredVersion;
} // getMinRequiredVersion


// -- METHOD ----------------------------------------------------------------
/** Visualization method.
@since    0.4.225
@return   a string visualization of this instance
*///-------------------------------------------------------------------------
@Override public String toString()
{
  return mPluginInterface.getName() + "-" + mMinRequiredVersion.getVersion();
} // toString


// ----- data members -----
/** the expected plugin interface class */
private Class mPluginInterface;
/** the minimum required plugin interface */
private ImmutableVersion mMinRequiredVersion;


} // class PluginHostRequirements
// --------------------------------------------------------------------------


// -- EOF -------------------------------------------------------------------
