// -- FILE ------------------------------------------------------------------
// name       : PluginLoaderImpl.java
// project    : BoarderZone: Libraries
// created    : Leon Poyyayil - 2005.06.26
// language   : java
// environment: JDK 1.5.0
// copyright  : (c) 1990-2008 by Leon Poyyayil (private), Switzerland
// license    : this is free software licensed under the GPL. see COPYING
// --------------------------------------------------------------------------
package net.boarderzone.plugin;

import net.boarderzone.util.JavaTool;
import net.boarderzone.util.Logger;
import net.boarderzone.util.lang.MessageResourceRegistry;


// -- CLASS -----------------------------------------------------------------
/** A basic implementation of the PluginLoader interface which just loads
classes through a normal java ClassLoader.
@author   Leon Poyyayil
@version  0.8.458
@since    0.4.225
*///-------------------------------------------------------------------------
public class PluginLoaderImpl implements PluginLoader {


// ----- constants -----
/** provides version information for this class/package */
public static final VersionInfo VERSION_INFO = VersionInfo.getInstance();


// -- METHOD ----------------------------------------------------------------
/** Creates a new instance which uses this class' ClassLoader.
@since    0.4.225
*///-------------------------------------------------------------------------
public PluginLoaderImpl()
{
  this( PluginLoaderImpl.class );
} // PluginLoaderImpl


// -- METHOD ----------------------------------------------------------------
/** Creates a new instance which the ClassLoader of the given class.
@since    0.4.225
@param    pClass the Class whose ClassLoader to use to locate classes. may not be null.
*///-------------------------------------------------------------------------
public PluginLoaderImpl(
  final Class pClass
)
{
  this( pClass.getClassLoader() );
} // PluginLoaderImpl


// -- METHOD ----------------------------------------------------------------
/** Creates a new instance which uses the given ClassLoader.
@since    0.4.225
@param    pLoader the ClassLoader to use to locate classes. may not be null.
*///-------------------------------------------------------------------------
public PluginLoaderImpl(
  final ClassLoader pLoader
)
{
  if ( pLoader == null ) {
    throw new NullPointerException();
  }
  mLoader = pLoader;
} // PluginLoaderImpl


// -- METHOD ----------------------------------------------------------------
/** {@inheritDoc}
@since    0.4.225
*///-------------------------------------------------------------------------
public Class loadPluginClass(
  final String pPluginClassName
) throws PluginNotFoundException
{
  if ( pPluginClassName == null ) {
    throw new NullPointerException();
  }
  try {
    final Class lPluginClass = mLoader.loadClass( pPluginClassName );
    ClassLoader lPluginClassLoader = lPluginClass.getClassLoader();
    if ( lPluginClassLoader == null ) {
      lPluginClassLoader = mLoader;
      LOGGER.warn( "class loader of " + lPluginClass + " is null" );
      LOGGER.warn( "registering " + mLoader + " instead" );
    }
    MessageResourceRegistry.getInstance().registerPackageClassLoader(
      JavaTool.getPackageName( pPluginClassName ), lPluginClassLoader );
    return lPluginClass;
  } catch ( ClassNotFoundException pExc ) {
    throw new PluginNotFoundException( pPluginClassName, pExc );
  }
} // loadPluginClass


// ----- data members -----
/** the logger to use for this class */
private static final Logger LOGGER = Logger.getLogger( PluginLoaderImpl.class );

/** the class loader to use to locate classes */
private ClassLoader mLoader;


} // class PluginLoaderImpl
// --------------------------------------------------------------------------


// -- EOF -------------------------------------------------------------------
